import subprocess
from datetime import datetime
import time


def grab():
    output = subprocess.check_output("pip freeze")
    output = output.decode("utf-8")
    # print(output)
    lines = output.split("\r\n")
    for line in lines:
        if line.startswith("WARNING"):
            lines.remove(line)

    return lines


def save(packages):
    filename = "data/" + datetime.now().strftime("%m_%d_%Y_%H_%M_%S")

    with open(filename, "w") as afile:
        for package in packages:
            afile.write(package + "\n")


def install(filename):
    output = subprocess.check_output(f"pip install -r {filename}")
    output = output.decode("utf-8")
    print(output)
    return output


def ticker(duration):
    print("[+] Loop Started")
    print(f"[+] Enivronment grabs after every {duration/60**3} hours")
    while True:
        packages = grab()
        save(packages)
        sleep(duration)


def sleep(n):
    for i in range(n):
        time.sleep(1)


# packages = grab()
# save(packages)

if __name__ == "__main__":
    import argparse

    parser = argparse.ArgumentParser(
        description="Grabs currently installed pip packages."
    )
    # parser.add_argument('module', metavar='grab', type=str, nargs='+', help='Runs the module')
    # parser.add_argument('module', metavar='module_name', type=str, nargs='+', help='Runs the module')
    parser.add_argument("-s", "--save", action="store_true", help="Save packages")
    parser.add_argument("-g", "--grab", action="store_true", help="Display packages")
    parser.add_argument(
        "-t", "--ticker", type=int, help="Save installed packages after N seconds",
    )

    args = parser.parse_args()

    import os

    if not os.path.exists("data"):
        os.makedirs("data")

    if args.grab:
        packages = grab()
        for package in packages:
            print(package)

    if args.save:
        packages = grab()
        save(packages)

    if args.ticker:
        ticker(args.ticker)



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="pip-grab",
    version="1.0.0.4",
    description="Grabs installed packages in pip every N seconds",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://QuantumNovice.github.io/pip-grab",
    author="QuantumNovice",
    author_email="portabl3lapy@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["pip-grab"],
    include_package_data=True,
    install_requires=[],
    #entry_points={"console_scripts": ["pip-grab=pip-grab.__main__:main",]},
    python_requires=">=3.6",
)
